@@ -113,6 +113,8 @@ from ncbi.datasets.openapi.model.v1_gene_descriptor_rna_type import V1GeneDescri
 from ncbi.datasets.openapi.model.v1_gene_descriptor_rna_type import V1GeneDescriptorRnaType as V1alpha1GeneDescriptorRnaType
 from ncbi.datasets.openapi.model.v1_gene_descriptors import V1GeneDescriptors
 from ncbi.datasets.openapi.model.v1_gene_descriptors import V1GeneDescriptors as V1alpha1GeneDescriptors
+from ncbi.datasets.openapi.model.v1_gene_group import V1GeneGroup
+from ncbi.datasets.openapi.model.v1_gene_group import V1GeneGroup as V1alpha1GeneGroup
 from ncbi.datasets.openapi.model.v1_gene_match import V1GeneMatch
 from ncbi.datasets.openapi.model.v1_gene_match import V1GeneMatch as V1alpha1GeneMatch
 from ncbi.datasets.openapi.model.v1_gene_metadata import V1GeneMetadata
